==> apache-camel-4.8.9-src.zip: apache-camel-4.8.9/core/camel-management/src/main/java/org/apache/camel/management/mbean/ManagedThroughputLogger.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.management.mbean;

import org.apache.camel.CamelContext;
import org.apache.camel.api.management.ManagedResource;
import org.apache.camel.api.management.mbean.ManagedThroughputLoggerMBean;
import org.apache.camel.model.ProcessorDefinition;
import org.apache.camel.support.processor.ThroughputLogger;

/**
 *
 */
@ManagedResource(description = "Managed ThroughputLogger")
public class ManagedThroughputLogger extends ManagedProcessor implements ManagedThroughputLoggerMBean {

    private final ThroughputLogger logger;

    public ManagedThroughputLogger(CamelContext context, ThroughputLogger logger, ProcessorDefinition<?> definition) {
        super(context, logger, definition);
        this.logger = logger;
    }

    public ThroughputLogger getLogger() {
        return logger;
    }

    @Override
    public void reset() {
        super.reset();
        logger.reset();
    }

    @Override
    public long getReceivedCounter() {
        return logger.getReceivedCounter();
    }

    @Override
    public double getAverage() {
        return logger.getAverage();
    }

    @Override
    public double getRate() {
        return logger.getRate();
    }

    @Override
    public String getLastLogMessage() {
        return logger.getLastLogMessage();
    }

    @Override
    public void resetThroughputLogger() {
        logger.reset();
    }
}

==> apache-camel-4.16.0-src.zip: apache-camel-4.16.0/core/camel-management/src/main/java/org/apache/camel/management/mbean/ManagedThroughputLogger.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.management.mbean;

import org.apache.camel.CamelContext;
import org.apache.camel.api.management.ManagedResource;
import org.apache.camel.api.management.mbean.ManagedThroughputLoggerMBean;
import org.apache.camel.model.ProcessorDefinition;
import org.apache.camel.support.processor.ThroughputLogger;

@ManagedResource(description = "Managed ThroughputLogger")
public class ManagedThroughputLogger extends ManagedProcessor implements ManagedThroughputLoggerMBean {

    public ManagedThroughputLogger(CamelContext context, ThroughputLogger logger, ProcessorDefinition<?> definition) {
        super(context, logger, definition);
    }

    @Override
    public ThroughputLogger getProcessor() {
        return (ThroughputLogger) super.getProcessor();
    }

    @Override
    public void reset() {
        super.reset();
        getProcessor().reset();
    }

    @Override
    public long getReceivedCounter() {
        return getProcessor().getReceivedCounter();
    }

    @Override
    public double getAverage() {
        return getProcessor().getAverage();
    }

    @Override
    public double getRate() {
        return getProcessor().getRate();
    }

    @Override
    public String getLastLogMessage() {
        return getProcessor().getLastLogMessage();
    }

    @Override
    public void resetThroughputLogger() {
        getProcessor().reset();
    }
}
